pub struct InitializeTree {
pub tree: Pubkey,
pub tree_controller: Pubkey,
pub authority: Pubkey,
pub payer: Pubkey,
pub ac_program: Pubkey,
pub noop_program: Pubkey,
pub system_program: Pubkey,
}Expand description
Generated client accounts for InitializeTree.
Fields
tree: Pubkeytree_controller: Pubkeypayer: Pubkeyac_program: Pubkeynoop_program: Pubkeysystem_program: PubkeyTrait Implementations
Sourceimpl BorshSerialize for InitializeTreewhere
Pubkey: BorshSerialize,
impl BorshSerialize for InitializeTreewhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for InitializeTree
impl ToAccountMetas for InitializeTree
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for InitializeTree
impl RefUnwindSafe for InitializeTree
impl Send for InitializeTree
impl Sync for InitializeTree
impl Unpin for InitializeTree
impl UnwindSafe for InitializeTree